import { scaleTime, scaleLog, extent, max, line, scaleLinear } from 'd3';
import { MarkerY } from './MarkerY';
import { XAxis } from './XAxis';
import { YAxis } from './YAxis';

export const LineChart = ({ data, width, height }) => {
  console.log(data);
  const xScale = scaleLinear()
      .domain((d) => d.month)
    .range([0, width]);

  const yScale = scaleLog()
    .domain([1, max(data, (d) => d.budget)])
    .range([height, 0]);

  const lineGen = line()
    .x((d) => xScale(d.month))
    .y((d) => yScale(d.budget));

  return (
    <>
      <XAxis xScale={xScale} height={height} />
      <YAxis yScale={yScale} width={width} />
      <MarkerY
        y={yScale(10000)}
        label="10,000 deaths"
        width={width}
      />
      <path d={lineGen(data)} />
      <g className="label">
        <text className="title">Global Coronavirus Deaths Over Time</text>
        <text
          transform={`translate(-50,${height}) rotate(-90)`}
        >
          Cumulative deaths
        </text>
        <text transform={`translate(0,${height + 50})`}>
          Date
        </text>
      </g>
    </>
  );
};
